@@ -530,13 +530,13 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
 %  The format of the GetImageConvexHull method is:
 %
 %      PointInfo *GetImageConvexHull(const Image *image,
-%        size_t number_coordinates,ExceptionInfo *exception)
+%        size_t number_vertices,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
-%    o number_coordinates: the number of coordinates in the convex hull.
+%    o number_vertices: the number of vertices in the convex hull.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -673,7 +673,7 @@ static PixelInfo GetEdgeBackgroundColor(const Image *image,
   return(edge_background);
 }
 
-void TraceConvexHull(PointInfo *coordinates,size_t number_coordinates,
+void TraceConvexHull(PointInfo *vertices,size_t number_vertices,
   PointInfo ***monotone_chain,size_t *chain_length)
 {
   PointInfo
@@ -691,26 +691,26 @@ void TraceConvexHull(PointInfo *coordinates,size_t number_coordinates,
   */
   chain=(*monotone_chain);
   n=0;
-  for (i=0; i < (ssize_t) number_coordinates; i++)
+  for (i=0; i < (ssize_t) number_vertices; i++)
   {
     while ((n >= 2) &&
-           (LexicographicalOrder(chain[n-2],chain[n-1],&coordinates[i]) <= 0.0))
+           (LexicographicalOrder(chain[n-2],chain[n-1],&vertices[i]) <= 0.0))
       n--;
-    chain[n++]=(&coordinates[i]);
+    chain[n++]=(&vertices[i]);
   }
   demark=n+1;
-  for (i=(ssize_t) number_coordinates-2; i >= 0; i--)
+  for (i=(ssize_t) number_vertices-2; i >= 0; i--)
   {
     while ((n >= demark) &&
-           (LexicographicalOrder(chain[n-2],chain[n-1],&coordinates[i]) <= 0.0))
+           (LexicographicalOrder(chain[n-2],chain[n-1],&vertices[i]) <= 0.0))
       n--;
-    chain[n++]=(&coordinates[i]);
+    chain[n++]=(&vertices[i]);
   }
   *chain_length=n;
 }
 
 MagickExport PointInfo *GetImageConvexHull(const Image *image,
-  size_t *number_coordinates,ExceptionInfo *exception)
+  size_t *number_vertices,ExceptionInfo *exception)
 {
   CacheView
     *image_view;
@@ -719,15 +719,15 @@ MagickExport PointInfo *GetImageConvexHull(const Image *image,
     status;
 
   MemoryInfo
-    *coordinate_info;
+    *vertices_info;
 
   PixelInfo
     background;
 
   PointInfo
     *convex_hull,
-    *coordinates,
-    **monotone_chain;
+    **monotone_chain,
+    *vertices;
 
   size_t
     n;
@@ -736,27 +736,27 @@ MagickExport PointInfo *GetImageConvexHull(const Image *image,
     y;
 
   /*
-    Identify convex hull coordinates of image foreground object(s).
+    Identify convex hull vertices of image foreground object(s).
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  *number_coordinates=0;
-  coordinate_info=AcquireVirtualMemory(image->columns,image->rows*
-    sizeof(*coordinates));
+  *number_vertices=0;
+  vertices_info=AcquireVirtualMemory(image->columns,image->rows*
+    sizeof(*vertices));
   monotone_chain=(PointInfo **) AcquireQuantumMemory(2*image->columns,2*
     image->rows*sizeof(*monotone_chain));
-  if ((coordinate_info == (MemoryInfo *) NULL) ||
+  if ((vertices_info == (MemoryInfo *) NULL) ||
       (monotone_chain == (PointInfo **) NULL))
     {
       if (monotone_chain != (PointInfo **) NULL)
         monotone_chain=(PointInfo **) RelinquishMagickMemory(monotone_chain);
-      if (coordinate_info != (MemoryInfo *) NULL)
-        coordinate_info=RelinquishVirtualMemory(coordinate_info);
+      if (vertices_info != (MemoryInfo *) NULL)
+        vertices_info=RelinquishVirtualMemory(vertices_info);
       return((PointInfo *) NULL);
     }
-  coordinates=(PointInfo *) GetVirtualMemoryBlob(coordinate_info);
+  vertices=(PointInfo *) GetVirtualMemoryBlob(vertices_info);
   image_view=AcquireVirtualCacheView(image,exception);
   background=GetEdgeBackgroundColor(image,image_view,exception);
   status=MagickTrue;
@@ -785,8 +785,8 @@ MagickExport PointInfo *GetImageConvexHull(const Image *image,
       GetPixelInfoPixel(image,p,&pixel);
       if (IsFuzzyEquivalencePixelInfo(&pixel,&background) == MagickFalse)
         {
-          coordinates[n].x=(double) x;
-          coordinates[n].y=(double) y;
+          vertices[n].x=(double) x;
+          vertices[n].y=(double) y;
           n++;
         }
       p+=GetPixelChannels(image);
@@ -796,14 +796,14 @@ MagickExport PointInfo *GetImageConvexHull(const Image *image,
   /*
     Return the convex hull of the image foreground object(s).
   */
-  TraceConvexHull(coordinates,n,&monotone_chain,number_coordinates);
-  convex_hull=(PointInfo *) AcquireQuantumMemory(*number_coordinates,
+  TraceConvexHull(vertices,n,&monotone_chain,number_vertices);
+  convex_hull=(PointInfo *) AcquireQuantumMemory(*number_vertices,
     sizeof(*convex_hull));
   if (convex_hull != (PointInfo *) NULL)
-    for (n=0; n < *number_coordinates; n++)
+    for (n=0; n < *number_vertices; n++)
       convex_hull[n]=(*monotone_chain[n]);
   monotone_chain=(PointInfo **) RelinquishMagickMemory(monotone_chain);
-  coordinate_info=RelinquishVirtualMemory(coordinate_info);
+  vertices_info=RelinquishVirtualMemory(vertices_info);
   return(convex_hull);
 }
 
@@ -1073,131 +1073,100 @@ MagickExport size_t GetImageDepth(const Image *image,ExceptionInfo *exception)
 %  The format of the GetImageMinimumBoundingBox method is:
 %
 %      PointInfo *GetImageMinimumBoundingBox(Image *image,
-%        size_t number_coordinates,ExceptionInfo *exception)
+%        size_t number_vertices,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o image: the image.
 %
-%    o number_coordinates: the number of coordinates in the convex hull.
+%    o number_vertices: the number of vertices in the bounding box.
 %
 %    o exception: return any errors or warnings in this structure.
 %
 */
 
-static double getAngle(const PointInfo *p,const PointInfo *q)
-{
-  /*
-    Angle in radians between vector p and q.
-  */
-  return(acos((p->x*q->x+p->y*q->y)*PerceptibleReciprocal(
-    sqrt(p->x*p->x+p->y*p->y)*sqrt(q->x*q->x+q->y*q->y))));
-}
-
-static double getDistance(const PointInfo *p,const PointInfo *q,
-  const PointInfo *v)
+typedef struct _CaliperInfo
 {
   double
-    gamma;
+    area,
+    width,
+    height,
+    projection;
 
+  ssize_t
+    p,
+    q,
+    v;
+} CaliperInfo;
+
+static inline double getAngle(PointInfo *p,PointInfo *q)
+{
   /*
-    Shortest distance between p to vector v through point q.
+    Get the angle between line (p,q) and horizontal axis, in degrees.
   */
-  if (fabs(v->x) < MagickEpsilon)
-    return(fabs(p->x-q->x));
-  gamma=v->y*PerceptibleReciprocal(v->x);
-  return(fabs(p->y-(q->y-gamma*q->x)-gamma*p->x)*
-    PerceptibleReciprocal(sqrt(gamma*gamma+1.0)));
+  return(RadiansToDegrees(atan2(q->y-p->y,q->x-p->x)));
 }
 
-static PointInfo getIntersection(const PointInfo *a,const PointInfo *b,
-  const PointInfo *c,const PointInfo *d)
+static inline double getDistance(PointInfo *p,PointInfo *q)
 {
-  PointInfo
-    p = { 0.0, 0.0 },
-    point = { 0.0, 0.0 },
-    q = { 0.0, 0.0 };
+  double
+    distance;
 
-  /*
-    Intersection: b passing through a and d passing c.
-  */
-  if ((fabs(b->x) < MagickEpsilon) && (fabs(d->x) < MagickEpsilon))
-    return(point);
-  if (fabs(b->x) >= MagickEpsilon)
-    {
-      q.x=b->y*PerceptibleReciprocal(b->x);
-      p.x=a->y-q.x*a->x;
-    }
-  if (fabs(d->x) >= MagickEpsilon)
-    {
-      q.y=d->y*PerceptibleReciprocal(d->x);
-      p.y=c->y-q.y*c->x;
-    }
-  if (fabs(b->x) < MagickEpsilon)
-    {
-      point.x=a->x;
-      point.y=q.y*a->x+p.y;
-      return(point);
-    }
-  if (fabs(d->x) <= MagickEpsilon)
-    {
-      point.x=c->x;
-      point.y=q.x*c->x+p.x;
-      return(point);
-    }
-  if (fabs(q.x-q.y) < MagickEpsilon)
-    return(point);
-  point.x=(p.y-p.x)*PerceptibleReciprocal(q.x-q.y);
-  point.y=q.x*point.x+p.x;
-  return(point);
+  distance=hypot(p->x-q->x,p->y-q->y);
+  return(distance*distance);
 }
 
-static PointInfo *getModuloPoint(PointInfo *points,const ssize_t n,
-  const size_t number_points)
+static inline double getProjection(PointInfo *p,PointInfo *q,PointInfo *v)
 {
-  return(points+(n % number_points));
-}
-
-static PointInfo rotateVector(const PointInfo *p,const double radians)
-{
-  PointInfo
-    point;
+  double
+    distance;
 
   /*
-    Rotates the vector p.
+    Projection of vector (x,y) - p into a line passing through p and q.
   */
-  point.x=p->x*cos(radians)-p->y*sin(radians);
-  point.y=p->x*sin(radians)+p->y*cos(radians);
-  return(point);
+  distance=getDistance(p,q);
+  if (distance < MagickEpsilon)
+    return(INFINITY);
+  return((q->x-p->x)*(v->x-p->x)+(v->y-p->y)*(q->y-p->y))/sqrt(distance);
+}
+
+static inline double getFeretDiameter(PointInfo *p,PointInfo *q,PointInfo *v)
+{
+  double
+    distance;
+
+  /*
+    Distance from a point (x,y) to a line passing through p and q.
+  */
+  distance=getDistance(p,q);
+  if (distance < MagickEpsilon)
+    return(INFINITY);
+  return((q->x-p->x)*(v->y-p->y)-(v->x-p->x)*(q->y-p->y))/sqrt(distance);
 }
 
 MagickExport PointInfo *GetImageMinimumBoundingBox(Image *image,
-  size_t *number_coordinates,ExceptionInfo *exception)
+  size_t *number_vertices,ExceptionInfo *exception)
 {
-  char
-    property[MagickPathExtent];
+  CaliperInfo
+    caliper_info;
+
+  const char
+    *artifact;
 
   double
-    min_area = 0.0,
-    min_height = 0.0,
-    min_width = 0.0,
-    radians = 0.0;
+    angle,
+    diameter,
+    distance;
 
   PointInfo
     *bounding_box,
-    caliper[4] = { { 1.0, 0.0 }, {-1.0, 0.0 }, { 0.0,-1.0 }, { 0.0, 1.0 } },
-    min_pair[4][2] = { { { 0.0, 0.0 }, { 0.0, 0.0 } },
-                       { { 0.0, 0.0 }, { 0.0, 0.0 } },
-                       { { 0.0, 0.0 }, { 0.0, 0.0 } },
-                       { { 0.0, 0.0 }, { 0.0, 0.0 } } },
-    *points;
+    *vertices;
+
+  register ssize_t
+    i;
 
   size_t
-    hull_length;
-
-  ssize_t
-    extent[4] = { 0, 0, 0, 0 },
-    n;
+    number_hull_vertices;
 
   /*
     Generate the minimum bounding box with the "Rotating Calipers" algorithm.
@@ -1206,148 +1175,200 @@ MagickExport PointInfo *GetImageMinimumBoundingBox(Image *image,
   assert(image->signature == MagickCoreSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  *number_coordinates=0;
-  points=GetImageConvexHull(image,&hull_length,exception);
-  if (points == (PointInfo *) NULL)
+  *number_vertices=0;
+  vertices=GetImageConvexHull(image,&number_hull_vertices,exception);
+  if (vertices == (PointInfo *) NULL)
     return((PointInfo *) NULL);
-  *number_coordinates=4;
-  bounding_box=(PointInfo *) AcquireQuantumMemory(*number_coordinates,
+  *number_vertices=4;
+  bounding_box=(PointInfo *) AcquireQuantumMemory(*number_vertices,
     sizeof(*bounding_box));
   if (bounding_box == (PointInfo *) NULL)
     {
-      points=(PointInfo *) RelinquishMagickMemory(points);
+      vertices=(PointInfo *) RelinquishMagickMemory(vertices);
       return((PointInfo *) NULL);
     }
-  for (n=1; n < (ssize_t) hull_length; n++)
-  {
-    if (points[n].y < points[extent[0]].y)
-      extent[0]=n;
-    if (points[n].y > points[extent[1]].y)
-      extent[1]=n;
-    if (points[n].x < points[extent[2]].x)
-      extent[2]=n;
-    if (points[n].x > points[extent[3]].x)
-      extent[3]=n;
-  }
-  while (radians < MagickPI)
+  caliper_info.area=2.0*image->columns*image->rows;
+  caliper_info.width=(double) image->columns+image->rows;
+  caliper_info.height=0.0;
+  caliper_info.projection=0.0;
+  caliper_info.p=(-1);
+  caliper_info.q=(-1);
+  caliper_info.v=(-1);
+  for (i=0; i < (ssize_t) number_hull_vertices; i++)
   {
     double
-      angle[4],
-      area,
-      height,
-      min_angle,
-      width;
+      area = 0.0,
+      max_projection = 0.0,
+      min_diameter = -1.0,
+      min_projection = 0.0;
 
-    PointInfo
-      edge[4];
+    register ssize_t
+      j,
+      k;
 
-    edge[0].x=getModuloPoint(points,extent[0]+1,hull_length)->x-
-      getModuloPoint(points,extent[0],hull_length)->x;
-    edge[0].y=getModuloPoint(points,extent[0]+1,hull_length)->y-
-      getModuloPoint(points,extent[0],hull_length)->y;
-    edge[1].x=getModuloPoint(points,extent[1]+1,hull_length)->x-
-      getModuloPoint(points,extent[1],hull_length)->x;
-    edge[1].y=getModuloPoint(points,extent[1]+1,hull_length)->y-
-      getModuloPoint(points,extent[1],hull_length)->y;
-    edge[2].x=getModuloPoint(points,extent[2]+1,hull_length)->x-
-      getModuloPoint(points,extent[2],hull_length)->x;
-    edge[2].y=getModuloPoint(points,extent[2]+1,hull_length)->y-
-      getModuloPoint(points,extent[2],hull_length)->y;
-    edge[3].x=getModuloPoint(points,extent[3]+1,hull_length)->x-
-      getModuloPoint(points,extent[3],hull_length)->x;
-    edge[3].y=getModuloPoint(points,extent[3]+1,hull_length)->y-
-      getModuloPoint(points,extent[3],hull_length)->y;
-    angle[0]=getAngle(&edge[0],&caliper[0]);
-    angle[1]=getAngle(&edge[1],&caliper[1]);
-    angle[2]=getAngle(&edge[2],&caliper[2]);
-    angle[3]=getAngle(&edge[3],&caliper[3]);
-    area=0.0;
-    min_angle=(double) ((float) MagickMin(MagickMin(MagickMin(angle[0],
-      angle[1]),angle[2]),angle[3]));
-    caliper[0]=rotateVector(&caliper[0],min_angle);
-    caliper[1]=rotateVector(&caliper[1],min_angle);
-    caliper[2]=rotateVector(&caliper[2],min_angle);
-    caliper[3]=rotateVector(&caliper[3],min_angle);
-    if (angle[0] == min_angle)
-      {
-        width=getDistance(getModuloPoint(points,extent[1],hull_length),
-          getModuloPoint(points,extent[0],hull_length),&caliper[0]);
-        height=getDistance(getModuloPoint(points,extent[3],hull_length),
-          getModuloPoint(points,extent[2],hull_length),&caliper[2]);
-      }
-    else
-      if (angle[1] == min_angle)
+    ssize_t
+      p = -1,
+      q = -1,
+      v = -1;
+
+    for (j=0; j < (ssize_t) number_hull_vertices; j++)
+    {
+      double
+        diameter;
+
+      diameter=fabs(getFeretDiameter(&vertices[i],
+        &vertices[(i+1) % number_hull_vertices],&vertices[j]));
+      if (min_diameter < diameter)
         {
-          width=getDistance(getModuloPoint(points,extent[0],hull_length),
-            getModuloPoint(points,extent[1],hull_length),&caliper[1]);
-          height=getDistance(getModuloPoint(points,extent[3],hull_length),
-            getModuloPoint(points,extent[2],hull_length),&caliper[2]);
+          min_diameter=diameter;
+          p=i;
+          q=(i+1) % number_hull_vertices;
+          v=j;
+        }
+    }
+    for (k=0; k < (ssize_t) number_hull_vertices; k++)
+    {
+      double
+        projection;
+
+      /*
+        Rotating calipers.
+      */
+      projection=getProjection(&vertices[p],&vertices[q],&vertices[k]);
+      min_projection=MagickMin(min_projection,projection);
+      max_projection=MagickMax(max_projection,projection);
+    }
+    area=min_diameter*(max_projection-min_projection);
+    if (caliper_info.area > area)
+      {
+        caliper_info.area=area;
+        caliper_info.width=min_diameter;
+        caliper_info.height=max_projection-min_projection;
+        caliper_info.projection=max_projection;
+        caliper_info.p=p;
+        caliper_info.q=q;
+        caliper_info.v=v;
+      }
+  }
+  /*
+    Initialize minimum bounding box.
+  */
+  diameter=getFeretDiameter(&vertices[caliper_info.p],
+    &vertices[caliper_info.q],&vertices[caliper_info.v]);
+  angle=atan2(vertices[caliper_info.q].y-vertices[caliper_info.p].y,
+    vertices[caliper_info.q].x-vertices[caliper_info.p].x);
+  bounding_box[0].x=vertices[caliper_info.p].x+cos(angle)*
+    caliper_info.projection;
+  bounding_box[0].y=vertices[caliper_info.p].y+sin(angle)*
+    caliper_info.projection;
+  bounding_box[1].x=bounding_box[0].x+cos(angle+MagickPI/2.0)*diameter;
+  bounding_box[1].y=bounding_box[0].y+sin(angle+MagickPI/2.0)*diameter;
+  bounding_box[2].x=bounding_box[1].x+cos(angle)*(-caliper_info.height);
+  bounding_box[2].y=bounding_box[1].y+sin(angle)*(-caliper_info.height);
+  bounding_box[3].x=bounding_box[2].x+cos(angle+MagickPI/2.0)*(-diameter);
+  bounding_box[3].y=bounding_box[2].y+sin(angle+MagickPI/2.0)*(-diameter);
+  /*
+    Export minimum bounding box properties.
+  */
+  (void) FormatImageProperty(image,"minimum-bounding-box:area","%.*g",
+    GetMagickPrecision(),caliper_info.area);
+  (void) FormatImageProperty(image,"minimum-bounding-box:width","%.*g",
+    GetMagickPrecision(),caliper_info.width);
+  (void) FormatImageProperty(image,"minimum-bounding-box:height","%.*g",
+    GetMagickPrecision(),caliper_info.height);
+  (void) FormatImageProperty(image,"minimum-bounding-box:_p","%.*g,%.*g",
+    GetMagickPrecision(),vertices[caliper_info.p].x,
+    GetMagickPrecision(),vertices[caliper_info.p].y);
+  (void) FormatImageProperty(image,"minimum-bounding-box:_q","%.*g,%.*g",
+    GetMagickPrecision(),vertices[caliper_info.q].x,
+    GetMagickPrecision(),vertices[caliper_info.q].y);
+  (void) FormatImageProperty(image,"minimum-bounding-box:_v","%.*g,%.*g",
+    GetMagickPrecision(),vertices[caliper_info.v].x,
+    GetMagickPrecision(),vertices[caliper_info.v].y);
+  /*
+    Find smallest angle to origin.
+  */
+  distance=hypot(bounding_box[0].x,bounding_box[0].y);
+  angle=getAngle(&bounding_box[0],&bounding_box[1]);
+  for (i=1; i < 4; i++)
+  {
+    double d = hypot(bounding_box[i].x,bounding_box[i].y);
+    if (d < distance)
+      {
+        distance=d;
+        angle=getAngle(&bounding_box[i],&bounding_box[(i+1) % 4]);
+      }
+  }
+  artifact=GetImageArtifact(image,"minimum-bounding-box:orientation");
+  if (artifact != (const char *) NULL)
+    {
+      double
+        length,
+        q_length,
+        p_length;
+
+      PointInfo
+        delta,
+        point;
+
+      /*
+        Find smallest perpendicular distance from edge to origin.
+      */
+      point=bounding_box[0];
+      for (i=1; i < 4; i++)
+      {
+        if (bounding_box[i].x < point.x)
+          point.x=bounding_box[i].x;
+        if (bounding_box[i].y < point.y)
+          point.y=bounding_box[i].y;
+      }
+      for (i=0; i < 4; i++)
+      {
+        bounding_box[i].x-=point.x;
+        bounding_box[i].y-=point.y;
+      }
+      for (i=0; i < 4; i++)
+      {
+        double
+          d,
+          intercept,
+          slope;
+
+        delta.x=bounding_box[(i+1) % 4].x-bounding_box[i].x;
+        delta.y=bounding_box[(i+1) % 4].y-bounding_box[i].y;
+        slope=delta.y*PerceptibleReciprocal(delta.x);
+        intercept=bounding_box[(i+1) % 4].y-slope*bounding_box[i].x;
+        d=fabs((slope*bounding_box[i].x-bounding_box[i].y+intercept)*
+          PerceptibleReciprocal(sqrt(slope*slope+1.0)));
+        if ((i == 0) || (d < distance))
+          {
+            distance=d;
+            point=delta;
+          }
+      }
+      angle=RadiansToDegrees(atan(point.y*PerceptibleReciprocal(point.x)));
+      length=hypot(point.x,point.y);
+      p_length=fabs((double) MagickMax(caliper_info.width,caliper_info.height)-
+        length);
+      q_length=fabs(length-(double) MagickMin(caliper_info.width,
+        caliper_info.height));
+      if (LocaleCompare(artifact,"landscape") == 0)
+        {
+          if (p_length > q_length)
+            angle+=(angle < 0.0) ? 90.0 : -90.0;
         }
       else
-        if (angle[2] == min_angle)
+        if (LocaleCompare(artifact,"portrait") == 0)
           {
-            width=getDistance(getModuloPoint(points,extent[1],hull_length),
-              getModuloPoint(points,extent[0],hull_length),&caliper[0]);
-            height=getDistance(getModuloPoint(points,extent[3],hull_length),
-              getModuloPoint(points,extent[2],hull_length),&caliper[2]);
+            if (p_length < q_length)
+              angle+=(angle >= 0.0) ? 90.0 : -90.0;
           }
-        else
-          {
-            width=getDistance(getModuloPoint(points,extent[1],hull_length),
-              getModuloPoint(points,extent[0],hull_length),&caliper[0]);
-            height=getDistance(getModuloPoint(points,extent[2],hull_length),
-              getModuloPoint(points,extent[3],hull_length),&caliper[3]);
-          }
-    radians+=min_angle;
-    area=width*height;
-    if ((fabs(min_area) < MagickEpsilon) || (area < min_area))
-      {
-        min_pair[0][0]=(*getModuloPoint(points,extent[0],hull_length));
-        min_pair[0][1]=caliper[0];
-        min_pair[1][0]=(*getModuloPoint(points,extent[1],hull_length));
-        min_pair[1][1]=caliper[1];
-        min_pair[2][0]=(*getModuloPoint(points,extent[2],hull_length));
-        min_pair[2][1]=caliper[2];
-        min_pair[3][0]=(*getModuloPoint(points,extent[3],hull_length));
-        min_pair[3][1]=caliper[3];
-        min_area=area;
-        min_width=width;
-        min_height=height;
-      }
-    if (fabs(angle[0]-min_angle) < MagickEpsilon)
-      extent[0]++;
-    else
-      if (fabs(angle[1]-min_angle) < MagickEpsilon)
-			  extent[1]++;
-      else
-        if (fabs(angle[2]-min_angle) < MagickEpsilon)
-          extent[2]++;
-        else
-          extent[3]++;
-    if (IsNaN(radians) != MagickFalse)
-      break;
-  }
-  bounding_box[0]=getIntersection(min_pair[0]+0,min_pair[0]+1,min_pair[3]+0,
-    min_pair[3]+1);
-  bounding_box[1]=getIntersection(min_pair[3]+0,min_pair[3]+1,min_pair[1]+0,
-    min_pair[1]+1);
-  bounding_box[2]=getIntersection(min_pair[1]+0,min_pair[1]+1,min_pair[2]+0,
-    min_pair[2]+1);
-  bounding_box[3]=getIntersection(min_pair[2]+0,min_pair[2]+1,min_pair[0]+0,
-    min_pair[0]+1);
-  (void) FormatLocaleString(property,MagickPathExtent,"%g",min_area);
-  (void) SetImageProperty(image,"minimum-bounding-box:area",property,exception);
-  (void) FormatLocaleString(property,MagickPathExtent,"%g",min_width);
-  (void) SetImageProperty(image,"minimum-bounding-box:width",property,
-    exception);
-  (void) FormatLocaleString(property,MagickPathExtent,"%g",min_height);
-  (void) SetImageProperty(image,"minimum-bounding-box:height",property,
-    exception);
-  (void) FormatLocaleString(property,MagickPathExtent,"%g",
-    RadiansToDegrees(radians));
-  (void) SetImageProperty(image,"minimum-bounding-box:angle",property,
-    exception);
-  points=(PointInfo *) RelinquishMagickMemory(points);
+    }
+  (void) FormatImageProperty(image,"minimum-bounding-box:angle","%.*g",
+    GetMagickPrecision(),angle);
+  (void) FormatImageProperty(image,"minimum-bounding-box:unrotate","%.*g",
+    GetMagickPrecision(),-angle);
+  vertices=(PointInfo *) RelinquishMagickMemory(vertices);
   return(bounding_box);
 }
 
